@@ -10,8 +10,6 @@ test_that("Input classes", {
   expect_error(sample_nc(mraster = mraster, nSamp = 4, iter = 100, algorithm = 4), "'algorithm' must be type character.")
   expect_error(sample_nc(mraster = mraster, nSamp = 50, plot = "A"), "'plot' must be type logical")
   expect_error(sample_nc(mraster = mraster, nSamp = 100, details = 1), "'details' must be type logical.")
-  expect_error(sample_nc(mraster = mraster, nSamp = 5, filename = TRUE), "'filename' must be a file path character string.")
-  expect_error(sample_nc(mraster = mraster, nSamp = 10, filename = file.path(tempdir(), "temp.shp"), overwrite = "A"), "'overwrite' must be type logical.")
 })
 
 test_that("Access", {
@@ -19,7 +17,6 @@ test_that("Access", {
   expect_message(sample_nc(mraster = mraster, nSamp = 5), "K-means being performed on 3 layers with 5 centers.")
   expect_message(sample_nc(mraster = mraster, nSamp = 5, access = access, buff_outer = 200), "An access layer has been provided. An external buffer of 200 m have been applied.")
   expect_message(sample_nc(mraster = mraster, nSamp = 5), "K-means being performed on 3 layers with 5 centers.")
-  expect_message(sample_nc(mraster = mraster, nSamp = 5, filename = file.path(tempdir(), "temp.shp"), overwrite = TRUE), "Output samples written to disc.")
 })
 
 test_that("details", {
